@@ -33,8 +33,8 @@ class ProviderDriver(object):
         a list of vip_dictionaries populated with data from the additional
         VIPs (which are guaranteed to be in the same Network).
         This might look like:
-        {'port_id': port_id, 'subnet_id': subnet_id_1, 'ip_address': ip1}, [
-            {'subnet_id': subnet_id_2, 'ip_address': ip2}, {...}, {...}]
+        {'port_id': port_id, 'subnet_id': subnet_id_1, 'ip_address': ip1},
+        [{'subnet_id': subnet_id_2, 'ip_address': ip2}, {...}, {...}]
         If the driver does not support port creation, the driver will raise
         a NotImplementedError.
 
@@ -285,9 +285,11 @@ class ProviderDriver(object):
             operator_fault_string='This provider does not support updating '
                                   'members.')
 
-    def member_batch_update(self, members):
+    def member_batch_update(self, pool_id, members):
         """Creates, updates, or deletes a set of pool members.
 
+        :param pool_id: The id of the pool to update.
+        :type pool_id: string
         :param members: List of member objects.
         :type members: list
         :return: Nothing if the create request was accepted.
@@ -491,3 +493,38 @@ class ProviderDriver(object):
                               'flavors.',
             operator_fault_string='This provider does not support validating '
                                   'the supported flavor metadata.')
+
+    # Availability Zone
+    def get_supported_availability_zone_metadata(self):
+        """Returns a dict of supported availability zone metadata keys.
+
+        The returned dictionary will include key/value pairs, 'name' and
+        'description.'
+
+        :returns: The availability zone metadata dictionary
+        :raises DriverError: An unexpected error occurred in the driver.
+        :raises NotImplementedError: The driver does not support flavors.
+        """
+        raise exceptions.NotImplementedError(
+            user_fault_string='This provider does not support getting the '
+                              'supported availability zone metadata.',
+            operator_fault_string='This provider does not support getting '
+                                  'the supported availability zone metadata.')
+
+    def validate_availability_zone(self, flavor_metadata):
+        """Validates if driver can support the availability zone.
+
+        :param availability_zone_metadata: Dictionary with az metadata.
+        :type availability_zone_metadata: dict
+        :return: Nothing if the availability zone is valid and supported.
+        :raises DriverError: An unexpected error occurred in the driver.
+        :raises NotImplementedError: The driver does not support availability
+          zones.
+        :raises UnsupportedOptionError: if driver does not
+          support one of the configuration options.
+        """
+        raise exceptions.NotImplementedError(
+            user_fault_string='This provider does not support validating '
+                              'availability zones.',
+            operator_fault_string='This provider does not support validating '
+                                  'the supported availability zone metadata.')
