@@ -34,6 +34,7 @@ MEMBERS = 'members'
 L7POLICIES = 'l7policies'
 L7RULES = 'l7rules'
 FLAVOR = 'flavor'
+OBJECT = 'object'
 
 # ID fields
 ID = 'id'
@@ -99,16 +100,24 @@ L7RULE_TYPE_PATH = 'PATH'
 L7RULE_TYPE_FILE_TYPE = 'FILE_TYPE'
 L7RULE_TYPE_HEADER = 'HEADER'
 L7RULE_TYPE_COOKIE = 'COOKIE'
+L7RULE_TYPE_SSL_CONN_HAS_CERT = 'SSL_CONN_HAS_CERT'
+L7RULE_TYPE_SSL_VERIFY_RESULT = 'SSL_VERIFY_RESULT'
+L7RULE_TYPE_SSL_DN_FIELD = 'SSL_DN_FIELD'
 SUPPORTED_L7RULE_TYPES = (L7RULE_TYPE_HOST_NAME, L7RULE_TYPE_PATH,
                           L7RULE_TYPE_FILE_TYPE, L7RULE_TYPE_HEADER,
-                          L7RULE_TYPE_COOKIE)
+                          L7RULE_TYPE_COOKIE, L7RULE_TYPE_SSL_CONN_HAS_CERT,
+                          L7RULE_TYPE_SSL_VERIFY_RESULT,
+                          L7RULE_TYPE_SSL_DN_FIELD)
+DISTINGUISHED_NAME_FIELD_REGEX = '^([a-zA-Z][A-Za-z0-9-]*)$'
 
 LB_ALGORITHM_ROUND_ROBIN = 'ROUND_ROBIN'
 LB_ALGORITHM_LEAST_CONNECTIONS = 'LEAST_CONNECTIONS'
 LB_ALGORITHM_SOURCE_IP = 'SOURCE_IP'
+LB_ALGORITHM_SOURCE_IP_PORT = 'SOURCE_IP_PORT'
 SUPPORTED_LB_ALGORITHMS = (LB_ALGORITHM_LEAST_CONNECTIONS,
                            LB_ALGORITHM_ROUND_ROBIN,
-                           LB_ALGORITHM_SOURCE_IP)
+                           LB_ALGORITHM_SOURCE_IP,
+                           LB_ALGORITHM_SOURCE_IP_PORT)
 
 OPERATING_STATUS = 'operating_status'
 ONLINE = 'ONLINE'
@@ -157,3 +166,96 @@ SUPPORTED_SP_TYPES = (SESSION_PERSISTENCE_SOURCE_IP,
 SUPPORTED_HTTP_HEADERS = ['X-Forwarded-For',
                           'X-Forwarded-Port',
                           'X-Forwarded-Proto']
+
+# List of SSL headers for client certificate
+SUPPORTED_SSL_HEADERS = ['X-SSL-Client-Verify', 'X-SSL-Client-Has-Cert',
+                         'X-SSL-Client-DN', 'X-SSL-Client-CN',
+                         'X-SSL-Issuer', 'X-SSL-Client-SHA1',
+                         'X-SSL-Client-Not-Before', 'X-SSL-Client-Not-After']
+
+# Constants from the provider driver API
+ACTION = 'action'
+ADDITIONAL_VIPS = 'additional_vips'
+ADDRESS = 'address'
+ADMIN_STATE_UP = 'admin_state_up'
+ALLOWED_CIDRS = 'allowed_cidrs'
+AVAILABILITY_ZONE = 'availability_zone'
+BACKUP = 'backup'
+CA_TLS_CONTAINER_DATA = 'ca_tls_container_data'
+CA_TLS_CONTAINER_REF = 'ca_tls_container_ref'
+CERTIFICATE = 'certificate'
+CLIENT_AUTHENTICATION = 'client_authentication'
+CLIENT_CA_TLS_CONTAINER_DATA = 'client_ca_tls_container_data'
+CLIENT_CA_TLS_CONTAINER_REF = 'client_ca_tls_container_ref'
+CLIENT_CRL_CONTAINER_DATA = 'client_crl_container_data'
+CLIENT_CRL_CONTAINER_REF = 'client_crl_container_ref'
+COMPARE_TYPE = 'compare_type'
+CONNECTION_LIMIT = 'connection_limit'
+COOKIE_NAME = 'cookie_name'
+CRL_CONTAINER_DATA = 'crl_container_data'
+CRL_CONTAINER_REF = 'crl_container_ref'
+DEFAULT_POOL = 'default_pool'
+DEFAULT_POOL_ID = 'default_pool_id'
+DEFAULT_TLS_CONTAINER_DATA = 'default_tls_container_data'
+DEFAULT_TLS_CONTAINER_REF = 'default_tls_container_ref'
+DELAY = 'delay'
+DESCRIPTION = 'description'
+DOMAIN_NAME = 'domain_name'
+EXPECTED_CODES = 'expected_codes'
+FALL_THRESHOLD = 'fall_threshold'
+HEALTHMONITOR = 'healthmonitor'
+HEALTHMONITOR_ID = 'healthmonitor_id'
+HTTP_METHOD = 'http_method'
+HTTP_VERSION = 'http_version'
+INSERT_HEADERS = 'insert_headers'
+INTERMEDIATES = 'intermediates'
+INVERT = 'invert'
+KEY = 'key'
+L7POLICY_ID = 'l7policy_id'
+L7RULE_ID = 'l7rule_id'
+LB_ALGORITHM = 'lb_algorithm'
+LISTENER_ID = 'listener_id'
+LOADBALANCER_ID = 'loadbalancer_id'
+MAX_RETRIES = 'max_retries'
+MAX_RETRIES_DOWN = 'max_retries_down'
+MEMBER_ID = 'member_id'
+MONITOR_ADDRESS = 'monitor_address'
+MONITOR_PORT = 'monitor_port'
+NAME = 'name'
+PASSPHRASE = 'passphrase'
+PERSISTENCE_GRANULARITY = 'persistence_granularity'
+PERSISTENCE_TIMEOUT = 'persistence_timeout'
+POOL_ID = 'pool_id'
+POSITION = 'position'
+PRIMARY_CN = 'primary_cn'
+PRIVATE_KEY = 'private_key'
+PROJECT_ID = 'project_id'
+PROTOCOL = 'protocol'
+PROTOCOL_PORT = 'protocol_port'
+REDIRECT_HTTP_CODE = 'redirect_http_code'
+REDIRECT_POOL_ID = 'redirect_pool_id'
+REDIRECT_PREFIX = 'redirect_prefix'
+REDIRECT_URL = 'redirect_url'
+RISE_THRESHOLD = 'rise_threshold'
+RULES = 'rules'
+SESSION_PERSISTENCE = 'session_persistence'
+SNI_CONTAINER_DATA = 'sni_container_data'
+SNI_CONTAINER_REFS = 'sni_container_refs'
+SUBNET_ID = 'subnet_id'
+TIMEOUT = 'timeout'
+TIMEOUT_CLIENT_DATA = 'timeout_client_data'
+TIMEOUT_MEMBER_CONNECT = 'timeout_member_connect'
+TIMEOUT_MEMBER_DATA = 'timeout_member_data'
+TIMEOUT_TCP_INSPECT = 'timeout_tcp_inspect'
+TLS_CONTAINER_DATA = 'tls_container_data'
+TLS_CONTAINER_REF = 'tls_container_ref'
+TLS_ENABLED = 'tls_enabled'
+TYPE = 'type'
+URL_PATH = 'url_path'
+VALUE = 'value'
+VIP_ADDRESS = 'vip_address'
+VIP_NETWORK_ID = 'vip_network_id'
+VIP_PORT_ID = 'vip_port_id'
+VIP_SUBNET_ID = 'vip_subnet_id'
+VIP_QOS_POLICY_ID = 'vip_qos_policy_id'
+WEIGHT = 'weight'
