@@ -44,6 +44,7 @@ class TestProviderDataModels(base.TestCase):
         self.healthmonitor_id = uuidutils.generate_uuid()
         self.l7policy_id = uuidutils.generate_uuid()
         self.l7rule_id = uuidutils.generate_uuid()
+        self.availability_zone = uuidutils.generate_uuid()
 
         self.ref_l7rule = data_models.L7Rule(
             admin_state_up=True,
@@ -98,7 +99,8 @@ class TestProviderDataModels(base.TestCase):
             client_ca_tls_container_data=None,
             client_ca_tls_container_ref=None,
             client_crl_container_data=None,
-            client_crl_container_ref=None)
+            client_crl_container_ref=None,
+            allowed_cidrs=None)
 
         self.ref_lb = data_models.LoadBalancer(
             admin_state_up=False,
@@ -112,7 +114,8 @@ class TestProviderDataModels(base.TestCase):
             vip_network_id=self.vip_network_id,
             vip_port_id=self.vip_port_id,
             vip_subnet_id=self.vip_subnet_id,
-            vip_qos_policy_id=self.vip_qos_policy_id)
+            vip_qos_policy_id=self.vip_qos_policy_id,
+            availability_zone=self.availability_zone)
 
         self.ref_vip = data_models.VIP(
             vip_address=self.vip_address,
@@ -200,7 +203,8 @@ class TestProviderDataModels(base.TestCase):
                             'description': 'One great load balancer',
                             'vip_subnet_id': self.vip_subnet_id,
                             'name': 'favorite_lb',
-                            'vip_qos_policy_id': self.vip_qos_policy_id}
+                            'vip_qos_policy_id': self.vip_qos_policy_id,
+                            'availability_zone': self.availability_zone}
 
         self.ref_listener_dict = {
             'admin_state_up': True,
@@ -229,7 +233,8 @@ class TestProviderDataModels(base.TestCase):
             'client_ca_tls_container_data': None,
             'client_ca_tls_container_ref': None,
             'client_crl_container_data': None,
-            'client_crl_container_ref': None, }
+            'client_crl_container_ref': None,
+            'allowed_cidrs': None, }
 
         self.ref_lb_dict_with_listener = {
             'admin_state_up': False,
@@ -243,7 +248,8 @@ class TestProviderDataModels(base.TestCase):
             'vip_network_id': self.vip_network_id,
             'vip_port_id': self.vip_port_id,
             'vip_subnet_id': self.vip_subnet_id,
-            'vip_qos_policy_id': self.vip_qos_policy_id}
+            'vip_qos_policy_id': self.vip_qos_policy_id,
+            'availability_zone': self.availability_zone}
 
         self.ref_vip_dict = {
             'vip_address': self.vip_address,
@@ -417,7 +423,8 @@ class TestProviderDataModels(base.TestCase):
             vip_network_id=self.vip_network_id,
             vip_port_id=self.vip_port_id,
             vip_subnet_id=self.vip_subnet_id,
-            vip_qos_policy_id=self.vip_qos_policy_id)
+            vip_qos_policy_id=self.vip_qos_policy_id,
+            availability_zone=self.availability_zone)
 
         ref_lb_dict_with_listener = deepcopy(self.ref_lb_dict_with_listener)
         ref_lb_dict_with_listener['pools'] = None
